@@ -11,7 +11,6 @@ filtertools     - Analysis of linear filters
 stimulustools   - Tools for getting stimulus history and statistics
 visualizations  - Tools for plotting receptive fields, filters, etc.
 nonlinearities  - Methods for estimating nonlinearities
-containers      - Objects for managing experimental data (stimuli and spikes)
 
 For more information, see the accompanying README.md
 
@@ -23,9 +22,8 @@ __all__ = [
     'stimulustools',
     'visualizations',
     'filtertools',
-    'containers'
     ]
 
-__version__ = '0.4.0'
+__version__ = '0.4.2'
 
 from pyret import *
